#!/bin/bash

#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# COPYRIGHT (c) 2003 European Southern Observatory
# LICENSE
#
# NAME:      test syntax of dpmkspace
# TYPE:      Bourne Shell script
# PROJECT:   VLT Data Flow System
# AUTHOR:    CG - ESO/DMD/SEG
# DESCRIPTION:
# USAGE:     vcsolac_tests.sh
# EXAMPLES:
#
# $Id
#
# who            when            what
#------------------------------------------------------------------------------
# C. Guirao      10/07/09        created
#------------------------------------------------------------------------------

echo_wait() {
    echo $NNN "$*" $CCC
}

bold_echo() {
    echo "$bon${*}$boff"
}

check_env_contains_value ()
{
  necho "Environment variable $3 "
  if check_string_contains_regexpr "$1" "$2" ; then
    return 0
  else
    return 1
  fi
}

#  TC0.1
TC0.1() {
  echo_wait "TC0.1: Check command vcsolac exists"
  if check_command_exist vcsolac; then
    bold_echo " ... GO" 
  else
    bold_echo " ... NOGO"; exit 1
  fi
}

#  TC0.2
TC0.2() {
  echo_wait "TC0.2: Check version of vcsolac"
  VCSOLOAC_RELEASE=4.3.7
  vcsolac_release=`vcsolac -version | gawk '{print $3}'`
  if [ "$VCSOLOAC_RELEASE" = "$vcsolac_release" ]; then
    bold_echo " ... GO" 
  else
    bold_echo " $vcsolac_release (expected $VCSOLAC_RELEASE)... NOGO"; result=1
  fi
}


#  TC1.1
TC1.1() {
  echo_wait "TC1.1: Check environment for vcsolac "
  if [ -z "$DFS_HOME" ]; then 
    bold_echo " ... NOGO. Environment DFS_HOME not defined."; result=1
    if ! check_directory_exist  $DFS_HOME ; then
      bold_echo " ... NOGO. Directory DFS_HOME does not exist."; result=1
    fi
  fi

  if ! check_env_contains_value $PATH $DFS_HOME PATH ; then
    bold_echo " ... NOGO. Directory $DFS_HOME not included in PATH."; result=1
  fi

  if ! check_env_contains_value $MANPATH $DFS_HOME/man MANPATH ; then
    bold_echo " ... NOGO. Directory $DFS_HOME/man not included in MANPATH."; result=1
  fi

  if ! check_directory_exist $DFS_HOME/man ; then
    bold_echo " ... NOGO. Directory DFS_HOME/man does not exist."; result=1
  fi

  if [ -z "$DHS_DATA" ]; then 
    bold_echo " ... NOGO. Environment DHS_DATA not defined."; result=1
    if ! check_directory_exist  $DHS_DATA ; then
      bold_echo " ... NOGO. Directory DHS_DATA does not exist."; result=1
    fi
  fi

  if [ -z "$DHS_LOG" ]; then 
    bold_echo " ... NOGO. Environment DHS_LOG not defined."; result=1
  else
    if ! check_directory_exist  $DHS_LOG ; then
      bold_echo " ... NOGO. Directory DHS_LOG does not exist."; result=1
    fi
  fi

  if [ -z "$BAD_DIR" ]; then 
    bold_echo " ... NOGO. Environment BAD_DIR not defined."; result=1
  else
    if ! check_directory_exist  $BAD_DIR ; then
      bold_echo " ... NOGO. Directory BAD_DIR does not exist."; result=1
    fi
  fi

  if [ -z "$DHS_HOST" ]; then 
    bold_echo " ... NOGO. Environment DHS_HOST not defined."; result=1
  else
    ping -c 1 -W 1 $DHS_HOST > /dev/null 2>&1
    if [ $? -ne 0 ]; then
      bold_echo " ... NOGO. Host $DHS_HOST does not respond to PING."; exit 1
    fi 
  fi

  if [ -z "$DHS_CONFIG" ]; then 
    bold_echo " ... NOGO. Environment DHS_CONFIG not defined."; exit 1
  fi

  if [ -z "$OLAS_ID" ]; then 
    bold_echo " ... NOGO. Environment OLAS_ID not defined."; result=1
  fi

  bold_echo " ... OK" 
}

#  TC1.2
TC1.2() {
  echo_wait "TC1.2: Check Remote Access to OlasWS"
  echo $DHS_CONFIG | grep -q "@${DHS_HOST}:"
  if [ $? != 0 ];  then
    bold_echo " ... NOGO. DHS_HOST is not part of DHS_CONFIG"; result=1
  fi    

  remote_account=`echo $DHS_CONFIG | gawk -F@ '{print $1}'`
  if ! check_access_host_account $DHS_HOST $remote_account ; then
    bold_echo " ... NOGO. No access to $DHS_HOST as $remote_account."; exit 1
  fi

  touch /tmp/${cmd}_$$
  rcp /tmp/${cmd}_$$ ${DHS_CONFIG}/ >/dev/null 2>&1
  if [ $? != 0 ]; then
    bold_echo " ... NOGO. No access to $DHS_CONFIG."
    rm -f /tmp/${cmd}_$$ ; exit 1
  fi
  rm -f /tmp/${cmd}_$$
  
  remote_dir=`echo $DHS_CONFIG | gawk -F: '{print $2}'`
  rsh -l $remote_account $DHS_HOST rm ${remote_dir}/${cmd}_$$
  if [ $? != 0 ]; then
    bold_echo " ... NOGO. No write permission to $DHS_CONFIG."
  fi

  bold_echo " ... OK" 
}

bon="[1m"
boff="[0m"

#
# ECHO=1 : functions necho() and myecho() enable (to print to terminal)
# ECHO=0 : functions necho() and myecho() disable (do not print anything)
#
ECHO=0
HOSTNAME=`uname -n`
cmd=`basename $0`
result=0
release=$Id

#
# Load dfschecklib.sh function library
#
dirname=`dirname $0`
library=$dirname/dfschecklib.sh
if [ ! -f $library ]; then
  echo "$cmd: Error loading $library. Exit"   
  exit 1
fi
. $library
set_echoes

#
# Print date, release and DFS release
#
echo  ""
echo "$cmd $release"
date
echo  ""

bold_echo "Test Suite 0: Preconditions"
TC0.1
TC0.2
bold_echo "Test Suite 1: Instrument Workstation"
TC1.1
TC1.2
exit
TC1.3
TC1.4
bold_echo "Test Suite 2: Olas Workstation"
TC2.1
TC2.2
TC2.3
TC2.4

exit $result
VCSOLAC_VERSION=`dpmkspace -version | gawk '{print $3}'
